.. :changelog:

History
-------

0.3 2013-10-16
++++++++++++++

* Added ability to specify restart command
* Added ability to cancel the restart

0.1 2013-10-15
++++++++++++++

* First functional release.

